==> jc-1.4.0.tar.gz: soot/util/IterableMap__24Mapping__5fIterator.h <==
// public class soot.util.IterableMap$Mapping_Iterator

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class b5d5117a3a1c9f97 soot_util_IterableMap__24Mapping__5fIterator

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_soot_util_IterableMap__24Mapping__5fIterator_H_
#define _JC_soot_util_IterableMap__24Mapping__5fIterator_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_util_HashMap$object;
struct _jc_java_util_Iterator$object;
struct _jc_soot_util_HashChain$object;
struct _jc_soot_util_IterableMap$object;

// Typedefs
typedef struct _jc_soot_util_IterableMap__24Mapping__5fIterator$sub_refs	_jc_soot_util_IterableMap__24Mapping__5fIterator$sub_refs;
typedef struct _jc_soot_util_IterableMap__24Mapping__5fIterator$sub_nonrefs	_jc_soot_util_IterableMap__24Mapping__5fIterator$sub_nonrefs;
typedef struct _jc_soot_util_IterableMap__24Mapping__5fIterator$refs	_jc_soot_util_IterableMap__24Mapping__5fIterator$refs;
typedef struct _jc_soot_util_IterableMap__24Mapping__5fIterator$nonrefs	_jc_soot_util_IterableMap__24Mapping__5fIterator$nonrefs;
typedef struct _jc_soot_util_IterableMap__24Mapping__5fIterator$object	_jc_soot_util_IterableMap__24Mapping__5fIterator$object;

typedef const struct _jc_soot_util_IterableMap__24Mapping__5fIterator$vmethods	_jc_soot_util_IterableMap__24Mapping__5fIterator$vmethods;
typedef const struct _jc_soot_util_IterableMap__24Mapping__5fIterator$vtable	_jc_soot_util_IterableMap__24Mapping__5fIterator$vtable;
typedef const struct _jc_soot_util_IterableMap__24Mapping__5fIterator$vtype	_jc_soot_util_IterableMap__24Mapping__5fIterator$vtype;

// Constructors
extern void _jc_soot_util_IterableMap__24Mapping__5fIterator$method$_init$32fb03b7492b87bc(_jc_env *, struct _jc_soot_util_IterableMap__24Mapping__5fIterator$object *, struct _jc_soot_util_IterableMap$object *, struct _jc_soot_util_HashChain$object *, struct _jc_java_util_HashMap$object *);

// Virtual methods
extern jboolean _jc_soot_util_IterableMap__24Mapping__5fIterator$method$hasNext$fb0bd5e38c59ddcd(_jc_env *, struct _jc_soot_util_IterableMap__24Mapping__5fIterator$object *);
extern struct _jc_java_lang_Object$object *_jc_soot_util_IterableMap__24Mapping__5fIterator$method$next$05874f79a1cf66ea(_jc_env *, struct _jc_soot_util_IterableMap__24Mapping__5fIterator$object *);
extern void _jc_soot_util_IterableMap__24Mapping__5fIterator$method$remove$fd50149979e1f350(_jc_env *, struct _jc_soot_util_IterableMap__24Mapping__5fIterator$object *);

// Virtual method descriptors
extern _jc_method _jc_soot_util_IterableMap__24Mapping__5fIterator$method_info$hasNext$fb0bd5e38c59ddcd;
extern _jc_method _jc_soot_util_IterableMap__24Mapping__5fIterator$method_info$next$05874f79a1cf66ea;
extern _jc_method _jc_soot_util_IterableMap__24Mapping__5fIterator$method_info$remove$fd50149979e1f350;

// Virtual methods structure
struct _jc_soot_util_IterableMap__24Mapping__5fIterator$vmethods {
	jboolean	(*hasNext$fb0bd5e38c59ddcd)(_jc_env *, struct _jc_soot_util_IterableMap__24Mapping__5fIterator$object *);
	struct _jc_java_lang_Object$object	*(*next$05874f79a1cf66ea)(_jc_env *, struct _jc_soot_util_IterableMap__24Mapping__5fIterator$object *);
	void	(*remove$fd50149979e1f350)(_jc_env *, struct _jc_soot_util_IterableMap__24Mapping__5fIterator$object *);
};

// Vtable
struct _jc_soot_util_IterableMap__24Mapping__5fIterator$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_util_IterableMap__24Mapping__5fIterator$vmethods	soot_util_IterableMap__24Mapping__5fIterator;
};

// Vtype
struct _jc_soot_util_IterableMap__24Mapping__5fIterator$vtype {
	_jc_type			type;
	_jc_soot_util_IterableMap__24Mapping__5fIterator$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_util_IterableMap__24Mapping__5fIterator$sub_refs {
	struct _jc_object	*it;
	struct _jc_java_util_HashMap$object	*m;
	struct _jc_soot_util_IterableMap$object	*this__240;
};

// Reference instance fields (object)
struct _jc_soot_util_IterableMap__24Mapping__5fIterator$refs {
    _jc_soot_util_IterableMap__24Mapping__5fIterator$sub_refs	soot_util_IterableMap__24Mapping__5fIterator;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_util_IterableMap__24Mapping__5fIterator$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_util_IterableMap__24Mapping__5fIterator$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_util_IterableMap__24Mapping__5fIterator$sub_nonrefs	soot_util_IterableMap__24Mapping__5fIterator;
};

// Object instance structure
struct _jc_soot_util_IterableMap__24Mapping__5fIterator$object {
	_jc_soot_util_IterableMap__24Mapping__5fIterator$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_util_IterableMap__24Mapping__5fIterator$vtype	*vtype;
	_jc_soot_util_IterableMap__24Mapping__5fIterator$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_util_IterableMap__24Mapping__5fIterator$vtype _jc_soot_util_IterableMap__24Mapping__5fIterator$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_util_IterableMap__24Mapping__5fIterator, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_util_IterableMap__24Mapping__5fIterator$class_object;

#endif	/* _JC_soot_util_IterableMap__24Mapping__5fIterator_H_ */

==> jc-1.4.6.tar.gz: soot/util/IterableMap__24Mapping__5fIterator.h <==
// public class soot.util.IterableMap$Mapping_Iterator

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class b5d5117a3a1c9f97 soot_util_IterableMap__24Mapping__5fIterator

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_soot_util_IterableMap__24Mapping__5fIterator_H_
#define _JC_soot_util_IterableMap__24Mapping__5fIterator_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_util_HashMap$object;
struct _jc_java_util_Iterator$object;
struct _jc_soot_util_HashChain$object;
struct _jc_soot_util_IterableMap$object;

// Typedefs
typedef struct _jc_soot_util_IterableMap__24Mapping__5fIterator$sub_refs	_jc_soot_util_IterableMap__24Mapping__5fIterator$sub_refs;
typedef struct _jc_soot_util_IterableMap__24Mapping__5fIterator$sub_nonrefs	_jc_soot_util_IterableMap__24Mapping__5fIterator$sub_nonrefs;
typedef struct _jc_soot_util_IterableMap__24Mapping__5fIterator$refs	_jc_soot_util_IterableMap__24Mapping__5fIterator$refs;
typedef struct _jc_soot_util_IterableMap__24Mapping__5fIterator$nonrefs	_jc_soot_util_IterableMap__24Mapping__5fIterator$nonrefs;
typedef struct _jc_soot_util_IterableMap__24Mapping__5fIterator$object	_jc_soot_util_IterableMap__24Mapping__5fIterator$object;

typedef const struct _jc_soot_util_IterableMap__24Mapping__5fIterator$vmethods	_jc_soot_util_IterableMap__24Mapping__5fIterator$vmethods;
typedef const struct _jc_soot_util_IterableMap__24Mapping__5fIterator$vtable	_jc_soot_util_IterableMap__24Mapping__5fIterator$vtable;
typedef const struct _jc_soot_util_IterableMap__24Mapping__5fIterator$vtype	_jc_soot_util_IterableMap__24Mapping__5fIterator$vtype;

// Constructors
extern void _jc_soot_util_IterableMap__24Mapping__5fIterator$method$_init$32fb03b7492b87bc(_jc_env *, struct _jc_soot_util_IterableMap__24Mapping__5fIterator$object *, struct _jc_soot_util_IterableMap$object *, struct _jc_soot_util_HashChain$object *, struct _jc_java_util_HashMap$object *) _JC_JCNI_ATTR;

// Virtual methods
extern jboolean _jc_soot_util_IterableMap__24Mapping__5fIterator$method$hasNext$fb0bd5e38c59ddcd(_jc_env *, struct _jc_soot_util_IterableMap__24Mapping__5fIterator$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_Object$object *_jc_soot_util_IterableMap__24Mapping__5fIterator$method$next$05874f79a1cf66ea(_jc_env *, struct _jc_soot_util_IterableMap__24Mapping__5fIterator$object *) _JC_JCNI_ATTR;
extern void _jc_soot_util_IterableMap__24Mapping__5fIterator$method$remove$fd50149979e1f350(_jc_env *, struct _jc_soot_util_IterableMap__24Mapping__5fIterator$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_soot_util_IterableMap__24Mapping__5fIterator$method_info$hasNext$fb0bd5e38c59ddcd;
extern _jc_method _jc_soot_util_IterableMap__24Mapping__5fIterator$method_info$next$05874f79a1cf66ea;
extern _jc_method _jc_soot_util_IterableMap__24Mapping__5fIterator$method_info$remove$fd50149979e1f350;

// Virtual methods structure
struct _jc_soot_util_IterableMap__24Mapping__5fIterator$vmethods {
	jboolean	(*hasNext$fb0bd5e38c59ddcd)(_jc_env *, struct _jc_soot_util_IterableMap__24Mapping__5fIterator$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_Object$object	*(*next$05874f79a1cf66ea)(_jc_env *, struct _jc_soot_util_IterableMap__24Mapping__5fIterator$object *) _JC_JCNI_ATTR;
	void	(*remove$fd50149979e1f350)(_jc_env *, struct _jc_soot_util_IterableMap__24Mapping__5fIterator$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_soot_util_IterableMap__24Mapping__5fIterator$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_util_IterableMap__24Mapping__5fIterator$vmethods	soot_util_IterableMap__24Mapping__5fIterator;
};

// Vtype
struct _jc_soot_util_IterableMap__24Mapping__5fIterator$vtype {
	_jc_type			type;
	_jc_soot_util_IterableMap__24Mapping__5fIterator$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_util_IterableMap__24Mapping__5fIterator$sub_refs {
	struct _jc_object	*it;
	struct _jc_java_util_HashMap$object	*m;
	struct _jc_soot_util_IterableMap$object	*this__240;
};

// Reference instance fields (object)
struct _jc_soot_util_IterableMap__24Mapping__5fIterator$refs {
    _jc_soot_util_IterableMap__24Mapping__5fIterator$sub_refs	soot_util_IterableMap__24Mapping__5fIterator;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_util_IterableMap__24Mapping__5fIterator$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_util_IterableMap__24Mapping__5fIterator$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_util_IterableMap__24Mapping__5fIterator$sub_nonrefs	soot_util_IterableMap__24Mapping__5fIterator;
};

// Object instance structure
struct _jc_soot_util_IterableMap__24Mapping__5fIterator$object {
	_jc_soot_util_IterableMap__24Mapping__5fIterator$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_util_IterableMap__24Mapping__5fIterator$vtype	*vtype;
	_jc_soot_util_IterableMap__24Mapping__5fIterator$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_util_IterableMap__24Mapping__5fIterator$vtype _jc_soot_util_IterableMap__24Mapping__5fIterator$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_util_IterableMap__24Mapping__5fIterator, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_util_IterableMap__24Mapping__5fIterator$class_object;

#endif	/* _JC_soot_util_IterableMap__24Mapping__5fIterator_H_ */
